# remirepo spec file for php-pecl-sdl-mixer
#
# Copyright (c) 2022-2023 Remi Collet
# License: CC-BY-SA-4.0
# http://creativecommons.org/licenses/by-sa/4.0/
#
# Please, preserve the changelog entries
#

%{?scl:%scl_package php-pecl-sdl-mixer}

%bcond_with         tests
%global with_zts    0%{!?_without_zts:%{?__ztsphp:1}}
%global pecl_name   sdl_mixer
# no ini file (loaded by phpsdl helper)

%global upstream_version 0.4.0
#global upstream_prever  RC1
%global sources          %{pecl_name}-%{upstream_version}%{?upstream_prever}
%global _configure       ../%{sources}/configure

Summary:        Binding of SDL_mixer for PHP
Name:           %{?scl_prefix}php-pecl-sdl-mixer
Version:        %{upstream_version}%{?upstream_prever:~%{upstream_prever}}
Release:        2%{?dist}%{!?scl:%{!?nophptag:%(%{__php} -r 'echo ".".PHP_MAJOR_VERSION.".".PHP_MINOR_VERSION;')}}

License:        zlib
URL:            https://pecl.php.net/package/%{pecl_name}
Source0:        https://pecl.php.net/get/%{sources}.tgz

BuildRequires:  make
BuildRequires:  %{?dtsprefix}gcc
BuildRequires:  %{?scl_prefix}php-devel >= 8.0
BuildRequires:  %{?scl_prefix}php-sdl >= 2.5.0
BuildRequires:  %{?scl_prefix}php-pear
BuildRequires:  SDL2_mixer-devel

Requires:       %{?scl_prefix}php(zend-abi) = %{php_zend_api}
Requires:       %{?scl_prefix}php(api) = %{php_core_api}
Requires:       %{?scl_prefix}php-sdl%{?_isa} >= 2.5.0
%if 0%{?fedora} >= 27 || 0%{?rhel} >= 8
Supplements:    %{?scl_prefix}php-sdl%{?_isa}
%endif

Provides:       %{?scl_prefix}php-%{pecl_name}               = %{version}
Provides:       %{?scl_prefix}php-%{pecl_name}%{?_isa}       = %{version}
Provides:       %{?scl_prefix}php-pecl(%{pecl_name})         = %{version}
Provides:       %{?scl_prefix}php-pecl(%{pecl_name})%{?_isa} = %{version}
# Notice pecl_name != name
Provides:       %{?scl_prefix}php-pecl-%{pecl_name}          = %{version}-%{release}
Provides:       %{?scl_prefix}php-pecl-%{pecl_name}%{?_isa}  = %{version}-%{release}


%description
SDL_mixer extension for PHP provides the binding of functions for audio
loading, playing and mixing.

Package built for PHP %(%{__php} -r 'echo PHP_MAJOR_VERSION.".".PHP_MINOR_VERSION;')%{?scl: as Software Collection (%{scl} by %{?scl_vendor}%{!?scl_vendor:rh})}.


%prep
%setup -qc

# Don't install/register tests
sed -e 's/role="test"/role="src"/' \
    %{?_licensedir:-e '/LICENSE/s/role="doc"/role="src"/' } \
    -i package.xml

cd %{sources}
# Check version as upstream often forget to update this
extver=$(sed -n '/define PHP_SDL_MIXER_VERSION/{s/.* "//;s/".*$//;p}' src/php_sdl_mixer.h)
if test "x${extver}" != "x%{upstream_version}%{?upstream_prever}%{?gh_date:-dev}"; then
   : Error: Upstream version is ${extver}, expecting %{upstream_version}%{?upstream_prever}%{?gh_date:-dev}.
   exit 1
fi
cd ..

mkdir NTS
%if %{with_zts}
mkdir ZTS
%endif


%build
%{?dtsenable}

peclconf() {
%configure \
    --enable-sdl_mixer \
    --with-php-config=$1
}

cd %{sources}
%{__phpize}

cd ../NTS
peclconf %{__phpconfig}
make %{?_smp_mflags}

%if %{with_zts}
cd ../ZTS
peclconf %{__ztsphpconfig}
make %{?_smp_mflags}
%endif


%install
%{?dtsenable}

# Install the NTS stuff
make -C NTS install INSTALL_ROOT=%{buildroot}

# Install XML package description
install -D -m 644 package.xml %{buildroot}%{pecl_xmldir}/%{name}.xml

# Install the ZTS stuff
%if %{with_zts}
make -C ZTS install INSTALL_ROOT=%{buildroot}
%endif

# Documentation
for i in $(grep 'role="doc"' package.xml | sed -e 's/^.*name="//;s/".*$//')
do [ -f %{sources}/$i ] &&  install -Dpm 644 %{sources}/$i %{buildroot}%{pecl_docdir}/%{pecl_name}/$i
done


%check
: Minimal load test for NTS extension
%{__php} --no-php-ini \
    --define extension=sdl \
    --define extension=%{buildroot}%{php_extdir}/%{pecl_name}.so \
    --modules | grep -i '^%{pecl_name}$'

%if %{with_zts}
: Minimal load test for ZTS extension
%{__ztsphp} --no-php-ini \
    --define extension=sdl \
    --define extension=%{buildroot}%{php_ztsextdir}/%{pecl_name}.so \
    --modules | grep -i '^%{pecl_name}$'

%endif

%if %{with tests}
cd %{sources}
: Run upstream test suite
# ignore deprecated (in SDL 2.5.0)
TEST_PHP_ARGS="-n -d error_reporting=24575 -d extension=sdl -d extension=%{buildroot}%{php_extdir}/%{pecl_name}.so" \
%{__php} -n run-tests.php -q --show-diff
%endif


%if 0%{?fedora} < 24 && 0%{?rhel} < 8
# when pear installed alone, after us
%triggerin -- %{?scl_prefix}php-pear
if [ -x %{__pecl} ] ; then
    %{pecl_install} %{pecl_xmldir}/%{name}.xml >/dev/null || :
fi

# posttrans as pear can be installed after us
%posttrans
if [ -x %{__pecl} ] ; then
    %{pecl_install} %{pecl_xmldir}/%{name}.xml >/dev/null || :
fi

%postun
if [ $1 -eq 0 -a -x %{__pecl} ] ; then
    %{pecl_uninstall} %{pecl_name} >/dev/null || :
fi
%endif


%files
%{?_licensedir:%license %{sources}/LICENSE}
%doc %{pecl_docdir}/%{pecl_name}
%{pecl_xmldir}/%{name}.xml

%{php_extdir}/%{pecl_name}.so

%if %{with_zts}
%{php_ztsextdir}/%{pecl_name}.so
%endif


%changelog
* Fri Sep  1 2023 Remi Collet <remi@remirepo.net> - 0.4.0-2
- build out of sources tree

* Tue Mar 15 2022 Remi Collet <remi@remirepo.net> - 0.4.0-1
- update to 0.4.0
- drop all patches, all merged upstream

* Mon Mar 14 2022 Remi Collet <remi@remirepo.net> - 0.3.0-2
- fix dependencies

* Mon Mar 14 2022 Remi Collet <remi@remirepo.net> - 0.3.0-1
- initial package
- open https://github.com/kea/php-sdl-mixer/pull/3
  SDL is required
- open https://github.com/kea/php-sdl-mixer/pull/4
  check if Mix_HasMusicDecoder is available
- open https://github.com/kea/php-sdl-mixer/pull/5
  split arginfo and properly init/quit library
